package com.backend.glowhouse.aws.sqs;

import com.backend.glowhouse.model.SensorData;
import com.backend.glowhouse.service.SensorDataService;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.aws.messaging.listener.annotation.SqsListener;
import org.springframework.messaging.handler.annotation.MessageMapping;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.Date;

@Component
public class SqsListenerEndpoint {
    private static Logger logger = LoggerFactory.getLogger(SqsListenerEndpoint.class);

    final private SensorDataService sensorDataService;

    @Autowired
    public SqsListenerEndpoint(SensorDataService sensorDataService) {
        this.sensorDataService = sensorDataService;
    }

    @MessageMapping
    @SqsListener(value = "sensor-data-queue")
    public void listenForSensorData(String message) throws IOException {
        logger.info("message received: {}", message);

        //Using jackson object mapper to parse json
        ObjectMapper sensorDataMapper = new ObjectMapper();
        SensorData data = sensorDataMapper.readValue(message, new TypeReference<SensorData>(){});
        data.setDate(new Date());

        this.sensorDataService.processSensorData(data);
    }
}