package com.backend.glowhouse.controller;

import com.backend.glowhouse.model.request.LoginRequest;
import com.backend.glowhouse.model.request.RegistrationRequest;
import com.backend.glowhouse.model.response.ApiResponse;
import com.backend.glowhouse.model.response.JwtAuthenticationResponse;
import com.backend.glowhouse.model.Role;
import com.backend.glowhouse.model.RoleType;
import com.backend.glowhouse.model.User;
import com.backend.glowhouse.repository.user.UserRepository;
import com.backend.glowhouse.security.JwtTokenProvider;
import com.backend.glowhouse.service.AuthenticationService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.support.ServletUriComponentsBuilder;

import javax.validation.Valid;
import java.net.URI;
import java.util.Collections;
import java.util.Date;

@RestController
@RequestMapping("/api/auth")
public class AuthenticationController {
    ObjectMapper mapper = new ObjectMapper();

    @Autowired
    private AuthenticationService authenticationService;

    @PostMapping("/login")
    public String authenticateUser(@Valid @RequestBody LoginRequest loginRequest) throws JsonProcessingException {
        return authenticationService.handleLoginRequest(loginRequest);
    }

    @PostMapping("/register")
    public ResponseEntity<?> registerUser(@Valid @RequestBody RegistrationRequest registrationRequest) {
        return authenticationService.handleRegistrationRequest(registrationRequest);
    }
}
