package com.backend.glowhouse.controller;

import com.backend.glowhouse.model.DataTableItem;
import com.backend.glowhouse.model.SensorData;
import com.backend.glowhouse.service.SensorDataService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.List;

@RestController
@RequestMapping("/api/sensorData")
public class SensorDataController {
    private ObjectMapper mapper = new ObjectMapper();
    private SensorDataService sensorDataService;

    @Autowired
    public SensorDataController(SensorDataService sensorDataService) {
        this.sensorDataService = sensorDataService;
    }

    @GetMapping("/aggregateData")
    @PreAuthorize("hasRole('USER')")
    public String aggregateSensorDataBetweenDates(
            @PathVariable(value = "deviceId") String deviceId,
            @PathVariable(value = "startTime") long startTime,
            @PathVariable(value = "endTime") long endTime,
            @PathVariable(value = "dataType") String dataType) throws JsonProcessingException {


        List<DataTableItem> sensorDataList = this.sensorDataService.retrieveSensorDataBetweenDates(deviceId, startTime, endTime, dataType);

        return mapper.writeValueAsString(sensorDataList);
    }
}
