package com.backend.glowhouse.repository.data;

import com.backend.glowhouse.model.DataTableItem;
import com.backend.glowhouse.model.SensorData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.mongodb.core.MongoTemplate;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

public class SensorDataRepositoryImpl implements SensorDataRepositoryCustom {
    private final MongoTemplate mongoTemplate;

    @Autowired
    public  SensorDataRepositoryImpl(MongoTemplate mongoTemplate) {
        this.mongoTemplate = mongoTemplate;
    }

    @Override
    public List<DataTableItem> findDataByDeviceIdBetweenDates(String deviceId, Date startDate, Date endDate, String dataType) {
        //Query for existing device
        Query query = new Query();
        query.addCriteria(Criteria.where("dId").is(deviceId));
        query.addCriteria(Criteria.where("date").gte(startDate));
        query.addCriteria(Criteria.where("date").lte(endDate));

        List<SensorData> sensorDataList = mongoTemplate.find(query, SensorData.class);

        List<DataTableItem> dataTable = new ArrayList<>();
        for (SensorData data : sensorDataList) {
            if (data.getDate() != null) {
                float value = 0f;

                switch (dataType) {
                    case "t":
                        value = data.getT();
                        break;
                    case "h":
                        value = data.getH();
                        break;
                    case "ph":
                        value = data.getPh();
                        break;
                }

                if (value != 0f) {
                    dataTable.add(new DataTableItem(data.getDate().getTime(), value));
                }
            }
        }

        return dataTable;
    }
}
