package com.backend.glowhouse.service;

import com.backend.glowhouse.model.Device;
import com.backend.glowhouse.model.request.DeviceRegistrationRequest;
import com.backend.glowhouse.model.response.ApiResponse;
import com.backend.glowhouse.model.response.DeviceIdResponse;
import com.backend.glowhouse.model.response.DeviceRegistrationResponse;
import com.backend.glowhouse.repository.device.DeviceRepository;
import com.backend.glowhouse.repository.user.UserRepository;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class DeviceService {
    private DeviceRepository deviceRepository;
    private UserRepository userRepository;

    ObjectMapper mapper = new ObjectMapper();

    @Autowired
    public DeviceService(DeviceRepository deviceRepository, UserRepository userRepository) {
        this.deviceRepository = deviceRepository;
        this.userRepository = userRepository;
    }

    public String handleDeviceRegistration(DeviceRegistrationRequest deviceRegistrationRequest) throws JsonProcessingException {
        String deviceId = deviceRegistrationRequest.getDeviceId();
        String username = deviceRegistrationRequest.getUsername();

        Device deviceToRegister = deviceRepository.registerUserToDevice(deviceId, username);

        if (deviceToRegister == null) {
            ApiResponse response = new ApiResponse(false, "The device does not exist");

            return mapper.writeValueAsString(response);
        }

        userRepository.registerDeviceToUser(username, deviceToRegister);

        DeviceRegistrationResponse deviceRegistrationResponse = new DeviceRegistrationResponse(deviceToRegister.getDeviceId());

        return mapper.writeValueAsString(deviceRegistrationResponse);
    }

    public String getDeviceIdForUser(String username) throws JsonProcessingException {
        Device device = deviceRepository.findByRegisteredUser(username);

        DeviceIdResponse deviceIdResponse = new DeviceIdResponse(device.getDeviceId());

        if (deviceIdResponse.getDeviceId() != null) {
            return mapper.writeValueAsString(deviceIdResponse);
        } else {
            return null;
        }
    }
}
