package com.backend.glowhouse.service;

import com.amazonaws.services.iot.client.AWSIotException;
import com.amazonaws.services.iot.client.AWSIotMqttClient;
import com.backend.glowhouse.config.AwsIotUtil;
import com.backend.glowhouse.model.DeviceShadow;
import com.backend.glowhouse.model.request.ShadowUpdateRequest;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

@Service
public class DeviceShadowService {
    private ObjectMapper mapper = new ObjectMapper();

    private String endpoint = "a2atwjvz13hwor-ats.iot.eu-west-1.amazonaws.com";
    private String clientId = "glowhouse_backend";
    private String cert = "/var/certs/cert.crt";
    private String key = "/var/certs/private.key";

    public String handleShadowGetRequest(String deviceId) throws AWSIotException {
        AwsIotUtil.KeyStorePasswordPair pair = AwsIotUtil.getKeyStorePasswordPair(cert, key, null);

        assert pair != null;
        AWSIotMqttClient awsIotClient = new AWSIotMqttClient(endpoint, clientId, pair.keyStore, pair.keyPassword);
        DeviceShadow deviceShadow = new DeviceShadow(deviceId);

        awsIotClient.attach(deviceShadow);
        awsIotClient.connect();

        String shadowJson = deviceShadow.get();
        awsIotClient.disconnect();

        return shadowJson;
    }

    public HttpStatus handleShadowUpdateRequest(ShadowUpdateRequest shadowUpdateRequest) throws AWSIotException, JsonProcessingException {
        String deviceShadowUpdate = "{\"state\": {\"desired\":" + mapper.writeValueAsString(shadowUpdateRequest.getShadowState().getDesired())  + "}}";

        AwsIotUtil.KeyStorePasswordPair pair = AwsIotUtil.getKeyStorePasswordPair(cert, key, null);

        assert pair != null;
        AWSIotMqttClient awsIotClient = new AWSIotMqttClient(endpoint, clientId, pair.keyStore, pair.keyPassword);
        DeviceShadow deviceShadow = new DeviceShadow(shadowUpdateRequest.getDeviceId());

        awsIotClient.attach(deviceShadow);
        awsIotClient.connect();

        deviceShadow.update(deviceShadowUpdate);
        awsIotClient.disconnect();

        return HttpStatus.OK;
    }
}
