package com.backend.glowhouse.service;

import com.backend.glowhouse.model.User;
import com.backend.glowhouse.model.exception.ResourceNotFoundException;
import com.backend.glowhouse.model.response.UserAvailability;
import com.backend.glowhouse.model.response.UserProfile;
import com.backend.glowhouse.model.response.UserSummary;
import com.backend.glowhouse.repository.user.UserRepository;
import com.backend.glowhouse.security.UserPrincipal;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class UserService {
    private UserRepository userRepository;
    private ObjectMapper mapper = new ObjectMapper();
    private static final Logger logger = LoggerFactory.getLogger(UserService.class);

    @Autowired
    public UserService(UserRepository userRepository) {
        this.userRepository = userRepository;
    }

    public String getCurrentUser(UserPrincipal currentUser) throws JsonProcessingException {
        UserSummary userSummary = new UserSummary(
                currentUser.getId(),
                currentUser.getUsername(),
                currentUser.getName()
        );

        return mapper.writeValueAsString(userSummary);
    }

    public String retrieveUserProfile(String username) throws JsonProcessingException {
        User user = userRepository.findByUsername(username)
                .orElseThrow(() -> new ResourceNotFoundException("User", "username", username));

        UserProfile profile = new UserProfile(
                user.getId(),
                user.getUsername(),
                user.getName(),
                user.getEmail(),
                user.getPassword(),
                user.getDevice().getDeviceId(),
                user.getJoinedAt().getTime()
        );

        return mapper.writeValueAsString(profile);
    }

    public UserAvailability checkEmailAvailability(String email) {
        if (userRepository.existsByEmail(email)) {
            return new UserAvailability(false);
        }
        return new UserAvailability(true);
    }

    public UserAvailability checkUsernameAvailability(String username) {
        if (userRepository.existsByUsername(username)) {
            return new UserAvailability(false);
        }
        return new UserAvailability(true);
    }
}
