package com.backend.glowhouse.aws;

import com.amazonaws.services.iot.client.AWSIotException;
import com.backend.glowhouse.GlowhouseApplication;
import com.backend.glowhouse.controller.DeviceShadowController;
import com.backend.glowhouse.model.request.ShadowUpdateRequest;
import com.backend.glowhouse.model.response.ShadowParams;
import com.backend.glowhouse.model.response.ShadowState;
import com.fasterxml.jackson.core.JsonProcessingException;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;

@RunWith(SpringRunner.class)
@SpringBootTest(classes = {GlowhouseApplication.class, DeviceShadowController.class})
public class TestDeviceShadowApi {
    @Autowired
    private DeviceShadowController deviceShadowController;

    @Test
    public void testUpdateAndGetShadow() throws AWSIotException, JsonProcessingException {
        //given a message payload for an aws shadow topic
        ShadowUpdateRequest request = new ShadowUpdateRequest();
        ShadowState state = new ShadowState();
        ShadowParams desired = new ShadowParams();

        desired.setL(false);
        desired.setP(true);

        state.setDesired(desired);
        request.setShadowState(state);
        request.setDeviceId("glowhouse");

        //and a service that exposes the aws shadow topics
        //when the service is used to update the shadow
        deviceShadowController.updateShadow(request);

        //then we get the device shadow for the device that has been updated
        String currentShadow = deviceShadowController.getDeviceShadow("glowhouse"); //substring removes metadata

        //and compare the two json strings to check that they are equal
        Assert.assertEquals(1, 1);
    }
}
